smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver

# ``smartcard`.`wx`.`SimpleSCardAppEventObserver`.`SimpleSCardAppEventObserver``

class documentation

`class SimpleSCardAppEventObserver(object):`

Known subclasses: `smartcard.wx.SimpleSCardAppFrame.BlankPanel`

View In Hierarchy

This interface defines the event handlers called by the SimpleSCardApp.

Method | `__init__` | Undocumented
Method | `OnActivateCard` | Called when a card is activated in the reader tree control or toolbar.
Method | `OnActivateReader` | Called when a reader is activated in the reader tree control or toolbar.
Method | `OnDeactivateCard` | Called when a card is deactivated in the reader tree control or toolbar.
Method | `OnDeselectCard` | Called when a card is selected in the reader tree control or toolbar.
Method | `OnSelectCard` | Called when a card is selected in the reader tree control or toolbar.
Method | `OnSelectReader` | Called when a reader is selected in the reader tree control or toolbar.
Instance Variable | `selectedcard` | Undocumented
Instance Variable | `selectedreader` | Undocumented

def __init__(self):
overridden in `smartcard.wx.SimpleSCardAppFrame.BlankPanel`

Undocumented

def OnActivateCard(self, card):

Called when a card is activated in the reader tree control or toolbar.

def OnActivateReader(self, reader):

Called when a reader is activated in the reader tree control or toolbar.

def OnDeactivateCard(self, card):

Called when a card is deactivated in the reader tree control or toolbar.

def OnDeselectCard(self, card):

Called when a card is selected in the reader tree control or toolbar.

def OnSelectCard(self, card):

Called when a card is selected in the reader tree control or toolbar.

def OnSelectReader(self, reader):

Called when a reader is selected in the reader tree control or toolbar.

selectedcard =

Undocumented

selectedreader =

Undocumented